@@ -20,7 +20,7 @@
 
 package App::MtAws::ConfigDefinition;
 
-our $VERSION = "0.973_01";
+our $VERSION = "0.973_02";
 
 use strict;
 use warnings;
@@ -345,8 +345,8 @@ sub get_config
 			/^[A-Za-z0-9\.\-_]{1,255}$/
 		};
 
-		command 'create-vault' => sub { validate(optional('config'), mandatory(@encodings), mandatory('vault-name'), mandatory(@config_opts), check_https),	};
-		command 'delete-vault' => sub { validate(optional('config'), mandatory(@encodings), mandatory('vault-name'), mandatory(@config_opts), check_https),	};
+		command 'create-vault' => sub { validate(optional('config'), mandatory(@encodings), mandatory('vault-name'), mandatory(@config_opts), check_https)};
+		command 'delete-vault' => sub { validate(optional('config'), mandatory(@encodings), mandatory('vault-name'), mandatory(@config_opts), check_https)};
 
 		command 'sync' => sub {
 			validate(mandatory(
